<?php

namespace OCA\PasswordsHandbook\Controller\Admin;

use JetBrains\PhpStorm\ArrayShape;
use OCA\Passwords\Exception\ApiException;
use OCA\PasswordsHandbook\Service\HandbookUrlService;
use OCP\AppFramework\ApiController;
use OCP\AppFramework\Http\JSONResponse;
use OCP\IConfig;
use OCP\IRequest;

class SettingsController extends ApiController {

    protected IConfig            $config;
    protected HandbookUrlService $handbookUrlService;

    /**
     * @param string   $appName
     * @param IConfig  $config
     * @param IRequest $request
     */
    public function __construct(
        string             $appName,
        IConfig            $config,
        IRequest           $request,
        HandbookUrlService $handbookUrlService
    ) {
        parent::__construct(
            $appName,
            $request,
            'PUT, GET, DELETE'
        );
        $this->config             = $config;
        $this->handbookUrlService = $handbookUrlService;
    }

    /**
     * @return JSONResponse
     */
    public function index(): JSONResponse {
        $settings = [
            $this->makeSetting('enabled', $this->handbookUrlService->isUrlSet())
        ];

        return new JSONResponse($settings);
    }

    /**
     * @param $id
     *
     * @return JSONResponse
     * @throws ApiException
     */
    public function show($id): JSONResponse {
        $data = [];
        if($id === 'enabled') {
            $data = $this->makeSetting('enabled', $this->handbookUrlService->isUrlSet());
        }

        return new JSONResponse($data);
    }

    /**
     * @param $id
     * @param $value
     *
     * @return JSONResponse
     * @throws ApiException
     */
    public function update($id, $value): JSONResponse {
        if($id === 'enabled') {
            if($value) {
                $this->handbookUrlService->setUrl();
            } else {
                $this->handbookUrlService->resetUrl();
            }
        }

        return $this->show($id);
    }

    /**
     * @param $id
     *
     * @return JSONResponse
     * @throws ApiException
     */
    public function destroy($id): JSONResponse {
        if($id === 'enabled') {
            $this->handbookUrlService->resetUrl();
        }

        return $this->show($id);
    }

    /**
     * @param $id
     * @param $value
     *
     * @return array
     */
    #[ArrayShape(['name' => "", 'value' => ""])] protected function makeSetting($id, $value): array {
        return [
            'name'  => $id,
            'value' => $value
        ];
    }
}