<?php

namespace OCA\PasswordsHandbook\Service;

use OCA\Passwords\Helper\Settings\ServerSettingsHelper;
use OCA\PasswordsHandbook\AppInfo\Application;
use OCP\IConfig;
use OCP\IURLGenerator;
use Psr\Log\LoggerInterface;
use Throwable;

class HandbookUrlService {
    protected IURLGenerator   $urlGenerator;
    protected IConfig         $config;
    protected LoggerInterface $logger;

    /**
     *
     */
    public function __construct(IURLGenerator $urlGenerator, IConfig $config, LoggerInterface $logger) {
        $this->urlGenerator = $urlGenerator;
        $this->config       = $config;
        $this->logger       = $logger;
    }

    /**
     * @return string
     */
    public function getUrl(): string {
        $handbookUrl = $this->urlGenerator->linkToRouteAbsolute('passwords_handbook.handbook.get', ['path' => 'PATH']);
        $handbookUrl = str_replace('PATH', '', $handbookUrl);

        return str_replace('http://', 'https://', $handbookUrl);
    }

    /**
     * @return string
     */
    public function getCurrentUrl(): string {
        return $this->config->getAppValue('passwords', 'handbook/url', ServerSettingsHelper::SERVER_MANUAL_URL);
    }

    /**
     * @return bool
     */
    public function isUrlSet(): bool {
        return $this->config->getAppValue('passwords', 'handbook/url') === $this->getUrl();
    }

    /**
     * @return void
     */
    public function setUrl() {
        $this->config->setAppValue('passwords', 'handbook/url', $this->getUrl());
    }

    /**
     * @return void
     */
    public function resetUrl() {
        try {
            if($this->isUrlSet()) {
                $this->config->deleteAppValue('passwords', 'handbook/url');
            }
        } catch(Throwable $e) {
            $this->logger->emergency($e->getMessage(), ['app' => Application::APP_NAME, 'exception' => $e]);
            $this->config->deleteAppValue('passwords', 'handbook/url');
        }
    }
}